Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2641)

Unified Diff: chrome/browser/history/thumbnail_database.h

Issue 330603004: Rename FaviconBitmapXxx to FaviconRawBitmapXxx (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/history/thumbnail_database.h
diff --git a/chrome/browser/history/thumbnail_database.h b/chrome/browser/history/thumbnail_database.h
index cc6324f292fde740dd15b99c897c5dc4d407e3dc..167a6d158b811042ca1a39f4b4e2c0186fcd2399 100644
--- a/chrome/browser/history/thumbnail_database.h
+++ b/chrome/browser/history/thumbnail_database.h
@@ -67,21 +67,21 @@ class ThumbnailDatabase {
// The list contains results for the bitmaps which are cached in the
// favicon_bitmaps table. The pixel sizes are a subset of the sizes in the
// 'sizes' field of the favicons table for |icon_id|.
- bool GetFaviconBitmapIDSizes(
+ bool GetFaviconRawBitmapIDSizes(
favicon_base::FaviconID icon_id,
- std::vector<FaviconBitmapIDSize>* bitmap_id_sizes);
+ std::vector<FaviconRawBitmapIDSize>* bitmap_id_sizes);
// Returns true if there are any matched bitmaps for the given |icon_id|. All
// matched results are returned if |favicon_bitmaps| is not NULL.
- bool GetFaviconBitmaps(favicon_base::FaviconID icon_id,
- std::vector<FaviconBitmap>* favicon_bitmaps);
+ bool GetFaviconRawBitmaps(favicon_base::FaviconID icon_id,
+ std::vector<FaviconRawBitmap>* favicon_bitmaps);
// Gets the last updated time, bitmap data, and pixel size of the favicon
// bitmap at |bitmap_id|. Returns true if successful.
- bool GetFaviconBitmap(FaviconBitmapID bitmap_id,
- base::Time* last_updated,
- scoped_refptr<base::RefCountedMemory>* png_icon_data,
- gfx::Size* pixel_size);
+ bool GetFaviconRawBitmap(FaviconRawBitmapID bitmap_id,
+ base::Time* last_updated,
+ scoped_refptr<base::RefCountedMemory>* png_icon_data,
+ gfx::Size* pixel_size);
// Adds a bitmap component at |pixel_size| for the favicon with |icon_id|.
// Only favicons representing a .ico file should have multiple favicon bitmaps
@@ -91,7 +91,7 @@ class ThumbnailDatabase {
// favicon should be refreshed.
// |pixel_size| is the pixel dimensions of |icon_data|.
// Returns the id of the added bitmap or 0 if unsuccessful.
- FaviconBitmapID AddFaviconBitmap(
+ FaviconRawBitmapID AddFaviconRawBitmap(
favicon_base::FaviconID icon_id,
const scoped_refptr<base::RefCountedMemory>& icon_data,
base::Time time,
@@ -100,18 +100,18 @@ class ThumbnailDatabase {
// Sets the bitmap data and the last updated time for the favicon bitmap at
// |bitmap_id|.
// Returns true if successful.
- bool SetFaviconBitmap(FaviconBitmapID bitmap_id,
- scoped_refptr<base::RefCountedMemory> bitmap_data,
- base::Time time);
+ bool SetFaviconRawBitmap(FaviconRawBitmapID bitmap_id,
+ scoped_refptr<base::RefCountedMemory> bitmap_data,
+ base::Time time);
// Sets the last updated time for the favicon bitmap at |bitmap_id|.
// Returns true if successful.
- bool SetFaviconBitmapLastUpdateTime(FaviconBitmapID bitmap_id,
- base::Time time);
+ bool SetFaviconRawBitmapLastUpdateTime(FaviconRawBitmapID bitmap_id,
+ base::Time time);
// Deletes the favicon bitmap with |bitmap_id|.
// Returns true if successful.
- bool DeleteFaviconBitmap(FaviconBitmapID bitmap_id);
+ bool DeleteFaviconRawBitmap(FaviconRawBitmapID bitmap_id);
// Favicons ------------------------------------------------------------------
@@ -142,7 +142,7 @@ class ThumbnailDatabase {
favicon_base::IconType icon_type);
// Adds a favicon with a single bitmap. This call is equivalent to calling
// AddFavicon and AddFaviconBitmap.
favicon_base::FaviconID AddFavicon(
const GURL& icon_url,
favicon_base::IconType icon_type,
@@ -142,7 +142,7 @@ class ThumbnailDatabase {
favicon_base::IconType icon_type);
// Adds a favicon with a single bitmap. This call is equivalent to calling
- // AddFavicon and AddFaviconBitmap.
+ // AddFavicon and AddFaviconRawBitmap.
favicon_base::FaviconID AddFavicon(
const GURL& icon_url,

Powered by Google App Engine
This is Rietveld 408576698